@@ -28,6 +28,7 @@ SITES = {
     'ifeng'            : 'ifeng',
     'imgur'            : 'imgur',
     'in'               : 'alive',
+    'infoq'            : 'infoq',
     'instagram'        : 'instagram',
     'interest'         : 'interest',
     'iqilu'            : 'iqilu',
@@ -40,7 +41,8 @@ SITES = {
     'ku6'              : 'ku6',
     'kugou'            : 'kugou',
     'kuwo'             : 'kuwo',
-    'letv'             : 'letv',
+    'le'               : 'le',
+    'letv'             : 'le',
     'lizhi'            : 'lizhi',
     'magisto'          : 'magisto',
     'metacafe'         : 'metacafe',
@@ -124,6 +126,10 @@ if sys.stdout.isatty():
 else:
     default_encoding = locale.getpreferredencoding().lower()
 
+def maybe_print(*s):
+    try: print(*s)
+    except: pass
+
 def tr(s):
     if default_encoding == 'utf-8':
         return s
@@ -364,6 +370,7 @@ def url_info(url, faker = False, headers = {}):
         'image/jpeg': 'jpg',
         'image/png': 'png',
         'image/gif': 'gif',
+        'application/pdf': 'pdf',
     }
     if type in mapping:
         ext = mapping[type]
@@ -950,8 +957,8 @@ def print_info(site_info, title, type, size):
     else:
         type_info = "Unknown type (%s)" % type
 
-    print("Site:      ", site_info)
-    print("Title:     ", unescape_html(tr(title)))
+    maybe_print("Site:      ", site_info)
+    maybe_print("Title:     ", unescape_html(tr(title)))
     print("Type:      ", type_info)
     print("Size:      ", round(size / 1048576, 2), "MiB (" + str(size) + " Bytes)")
     print()
@@ -1129,7 +1136,7 @@ def script_main(script_name, download, download_playlist, **kwargs):
 
         elif o in ('-l', '--playlist'):
             playlist = True
-        elif o in ('--no-caption'):
+        elif o in ('--no-caption',):
             caption = False
         elif o in ('-n', '--no-merge'):
             merge = False
